From 73130e5963a2c18d2c053332e273e8a426e93307 Mon Sep 17 00:00:00 2001
From: wk3368 <wk3368@163.com>
Date: Tue, 26 Apr 2022 09:21:43 +0800
Subject: [PATCH] fix: empty string should return Uint8Array(1)[0], instead of
 emptey <Buffer>

---
 src/encoding/index.spec.ts | 23 ++++++++++++++++++++---
 src/utils/tx.ts            |  7 ++-----
 2 files changed, 22 insertions(+), 8 deletions(-)

diff --git a/src/encoding/index.spec.ts b/src/encoding/index.spec.ts
index b145f73..85fd58d 100644
--- a/src/encoding/index.spec.ts
+++ b/src/encoding/index.spec.ts
@@ -289,14 +289,31 @@ test("encodeScriptFunctionByResolve4", async () => {
   // expect(payloadInHex).toBe(hexExpected);
 }, 10000);
 
+test("encodeScriptFunctionByResolve5", async () => {
+  const nft = {
+    name: 'mytestnft',
+    image: 'ipfs:://QmSPcvcXgdtHHiVTAAarzTeubk5X3iWymPAoKBfiRFjPMY',
+    description: '',
+  }
+  const functionId = '0x2c5bd5fb513108d4557107e09c51656c::SimpleNFTScripts::mint_with_image'
+  const tyArgs = []
+  const args = [nft.name, nft.image, nft.description]
+
+  const nodeUrl = 'https://barnard-seed.starcoin.org'
+
+  const scriptFunction = await encodeScriptFunctionByResolve(functionId, tyArgs, args, nodeUrl)
+  expect(args[2]).toBe('');
+  expect(scriptFunction.value.args[2].length).toBe(1);
+  expect(scriptFunction.value.args[2][0]).toBe(0);
+}, 10000);
 
 test("encodeScriptFunctionByResolve6", async () => {
   const STC_SCALLING_FACTOR = 1000000000
-  const addressArray =  ["0x22a19240709CB17ec9523252AA17B997"];
+  const addressArray = ["0x22a19240709CB17ec9523252AA17B997"];
   const amountArray = [11 * STC_SCALLING_FACTOR];
   const functionId = '0x1::TransferScripts::batch_peer_to_peer_v2'
   const typeArgs = ['0x1::STC::STC']
-  const args = [addressArray,amountArray]
+  const args = [addressArray, amountArray]
 
   const nodeUrl = 'https://barnard-seed.starcoin.org'
   const scriptFunction = await encodeScriptFunctionByResolve(functionId, typeArgs, args, nodeUrl);
@@ -304,7 +321,7 @@ test("encodeScriptFunctionByResolve6", async () => {
   const se = new BcsSerializer();
   scriptFunction.serialize(se);
   const payloadInHex = toHexString(se.getBytes());
-  const hexExpected = "0x02000000000000000000000000000000010f5472616e73666572536372697074731562617463685f706565725f746f5f706565725f763201070000000000000000000000000000000103535443035354430002110122a19240709cb17ec9523252aa17b997110100aea68f020000000000000000000000";
+  const hexExpected = "0x02000000000000000000000000000000010f5472616e73666572536372697074731562617463685f706565725f746f5f706565725f76320107000000000000000000000000000000010353544303535443000212011022a19240709cb17ec9523252aa17b997110100aea68f020000000000000000000000";
   expect(payloadInHex).toBe(hexExpected);
 }, 10000);
 
diff --git a/src/utils/tx.ts b/src/utils/tx.ts
index b000de7..b64289e 100644
--- a/src/utils/tx.ts
+++ b/src/utils/tx.ts
@@ -257,10 +257,7 @@ function serializeWithType(
   const se = new BcsSerializer();
 
   if (type && type.Vector === 'U8') {
-    if (!value) {
-      return Buffer.from('')
-    }
-    const valueBytes = isHexString(addHexPrefix(value)) ? fromHexString(value) : new Uint8Array(Buffer.from(value))
+    const valueBytes = value ? (isHexString(addHexPrefix(value)) ? fromHexString(value) : new Uint8Array(Buffer.from(value))) : new Uint8Array()
     const { length } = valueBytes;
     const list: Seq<uint8> = [];
     for (let i = 0; i < length; i++) {
@@ -322,7 +319,7 @@ export async function encodeScriptFunctionByResolve(
     argsType.shift();
   }
 
-  const argsBytes = encodeScriptFunctionArgs(argsType, args)
+  const argsBytes = encodeScriptFunctionArgs(argsType, args);
 
   return encodeScriptFunction(functionId, tyArgs, argsBytes);
 }
